govcl

command module
v1.1.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2018 License: LGPL-2.1 Imports: 7 Imported by: 0

README

govcl: Go bindings Delphi VCL/Lazarus LCL



Support win32, win64, linux64, macOS32 (linux and macOS only part of the components, properties, events and methods are valid)

See more screenshots

Go Version >= 1.9.0

usage:

go get github.com/ying32/govcl

package main

import (
   "github.com/ying32/govcl/vcl"
)

var (
   mainForm *vcl.TForm
)

func main() {
    vcl.Application.Initialize()
    mainForm = vcl.Application.CreateForm()
    mainForm.SetCaption("Hello")
    mainForm.EnabledMaximize(false)
    mainForm.ScreenCenter()
    vcl.Application.Run()
}


FAQ

Q: Why is there no English WIKI?
A: My English is bad. You can use Google Translate.


Other

binaries download .

  • Windows: copy "bin\win32\libvcl.dll" or "bin\win64\libvclx64.dll" to the current exe directory or system environment path. If you don't want to use Delphi binary, you can copy the corresponding LCL library binaries under the "bin\liblcl.dll" directory. Note: the use of LCL is limited in components, events, properties, and methods.

  • Linux: copy "bin\linux64\liblcl.so" executable file directory (also can be copied from the liblcl.so to /usr/lib/ directory as a Public Library).

  • MacOS: copy "bin\MacOS32\liblcl.dylib" executable file directory. APP package.


Documentation

Overview

govcl project main.go go.exe build -i -ldflags="-H windowsgui"

Directories

Path Synopsis
samples
OSVersion command
SkinsharpTest command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
WindowsMessages command
WindowsProcess command
WindowsTest command
action command
basic command
basicResForm command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
checklistbox command
draganddrop command
draw command
dropfiles command
eventpublic command
formEvents command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
gdiplustest command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
gdiplustest2 command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
imagebutton command
imageviewer command
由GOVCL UI设计器自动生成,不要编辑
由GOVCL UI设计器自动生成,不要编辑
inifile command
layout command
listview command
listviewcustomdraw command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
memstream command
menu command
msgbox command
notepad command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
registry command
richedit command
statusbar command
stdcontrols command
style command
sysdialog command
trayicon command
treeview command
wingif command
xunleidownloader command
由GOVCL UI设计器自动生成,不要编辑。
由GOVCL UI设计器自动生成,不要编辑。
vcl
api
---------------------------------------- 加载文件或者内存中的窗口资源文件功能 本文件内部函数不在开源范围内 需要配合窗口设计器使用 Copyright © ying32.
---------------------------------------- 加载文件或者内存中的窗口资源文件功能 本文件内部函数不在开源范围内 需要配合窗口设计器使用 Copyright © ying32.
exts/skinh
skinsharp皮肤扩展接口 http://www.skinsharp.com/htdocs/index.htm skinsharp是收费的,这里只是头文件的导入。
skinsharp皮肤扩展接口 http://www.skinsharp.com/htdocs/index.htm skinsharp是收费的,这里只是头文件的导入。
rtl
win

Jump to